@@ -306,31 +306,81 @@ maxlik_cov_sp_check_arg <- function(X, y, coords, sp.type,
 	}
 }
 
-krige_arg_check <- function(y, V, Vp, Vop, X, Xp, coeff)
+maxlik_cov_st_check_arg <- function(X, y, coords, time = time, sp.type, 
+	range.par, error.ratio, smoothness, t.type = "ar1", D, T, reml, lower, upper)
+{
+	if(!is.numeric(X) || !is.matrix(X)){ stop("X must be a numeric matrix") }
+	if(!is.numeric(y)){ stop("y must be numeric") }
+	if(!is.numeric(coords) || !is.numeric(coords)){ stop("coords must be a numeric matrix") }
+	if(!valid_sp_type(sp.type)){ stop("specified sp.type is not a valid covariance type") }
+	if(!(range.par > 0)){ stop("range.par must be positive") }
+	if(!(error.ratio >= 0)){ stop("range.par must be non-negative") }
+	if(!(smoothness > 0)){ stop("smoothness must be positive") }
+	if(t.type != "ar1"){ stop("ar1 is the only valid option for t.type") }
+	if(!is.null(D))
+	{
+		if(!is.numeric(D) || !is.matrix(D))
+		{ 
+			stop("If supplied, D must be a numeric matrix") 
+		}
+	}
+	if(!is.null(T))
+	{
+		if(!is.numeric(T) || !is.matrix(T))
+		{ 
+			stop("If supplied, T must be a numeric matrix") 
+		}
+	}
+
+	if(!is.logical(reml)){ stop("reml must be a logical value") }
+	if(!is.null(lower))
+	{
+		if(!is.numeric(lower)){ stop("lower must be a numeric vector")} 
+	}
+	if(!is.null(upper))
+	{
+		if(!is.numeric(upper)){ stop("upper must be a numeric vector")} 
+	}
+	if(!is.null(lower) && !is.null(upper))
+	{
+		if(length(lower) != length(upper)){ stop("lower and upper should have the same length") }
+	}
+}
+
+krige_arg_check <- function(y, V, Vp, Vop, X, Xp, m, return.w, nsim, Ve.diag, method)
 {
-	n <- length(y)
 
 	if(!is.numeric(y))
 	{
-		stop("y must be a numeric vector")
+		stop("y must be numeric")
 	}
+	if(!is.vector(y))
+	{
+		stop("y must be a vector")
+	}
+
+	n <- length(y)
+
 	if(!is.matrix(V) || !is.numeric(V) || (nrow(V)!= ncol(V)))
 	{
 		stop("V must be a square numeric matrix")
 	}
+	if(nrow(V) != n)
+	{
+		stop("nrow(V) must equal length(y))")
+	}
+
 	if(!is.matrix(Vp) || !is.numeric(Vp) || (nrow(Vp)!= ncol(Vp)))
 	{
 		stop("Vp must be a square numeric matrix")
 	}
+
 	if(!is.matrix(Vop) || !is.numeric(Vop))
 	{
 		stop("Vop must be a numeric matrix")
 	}
-	if(length(y) != nrow(V))
-	{
-		stop("length(y) must equal nrow(V)")
-	}
-	if(length(y) != nrow(Vop))
+
+	if(n != nrow(Vop))
 	{
 		stop("length(y) must equal nrow(Vop)")
 	}
@@ -338,10 +388,12 @@ krige_arg_check <- function(y, V, Vp, Vop, X, Xp, coeff)
 	{
 		stop("ncol(Vp) must equal ncol(Vop)")
 	}
+	
 	if((is.null(X) && !is.null(Xp)) || (!is.null(X) && is.null(Xp)))
 	{
 		stop("If X is supplied, Xp must also be supplied (and vice versa)")
 	}
+
 	if(!is.null(X))
 	{
 		if(nrow(X) != n)
@@ -357,20 +409,57 @@ krige_arg_check <- function(y, V, Vp, Vop, X, Xp, coeff)
 			stop("ncol(Xp) must equal ncol(X)")
 		}
 	}
-	if(!is.null(coeff))
+	
+	if(!(is.numeric(m) && length(m) == 1))
 	{
-		if(!is.numeric(coeff))
+		stop("m must be a numeric vector of length 1")
+	}
+
+	if(length(return.w) != 1)
+	{
+		stop("return.w must be TRUE or FALSE")
+	}
+	if(!((return.w == TRUE) || (return.w == FALSE)))
+	{
+		stop("return.w must be TRUE or FALSE")
+	}
+
+	if(!(is.numeric(nsim) && length(nsim) == 1 && (nsim >= 0)))
+	{
+		stop("nsim must be a nonnegative value")
+	}
+
+	if(nsim >= 1)
+	{
+		if(!(is.vector(Ve.diag) && length(Ve.diag) == n && min(Ve.diag) >= 0))
 		{
-			stop("coeff must be a numeric vector")
+			stop("Ve.diag must be a vector of length n with non-negative values")
 		}
-		if(length(coeff) > 1)
+		if(!(method == "eigen" || method == "chol" || method == "svd"))
 		{
-			if(length(coeff) != ncol(X))
-			{
-				stop("length(coeff) must equal ncol(X)")
-			}
+			stop("method must be 'eigen', 'chol', or 'svd'")
 		}
 	}
+	else
+	{
+		Ve.diag <- 1
+	}
+	
+	# change method to number for C++ function
+	if(method == "eigen"){ method <- 1 }
+	else if(method == "chol"){ method <- 2}
+	else{ method <- 3 }
+	
+	# change rws to number for C++ function
+	if(return.w == TRUE)
+	{
+		rws <- 1
+	}
+	else
+	{
+		rws <- 0
+	}
+	return(list(rws = rws, method = method, Ve.diag = Ve.diag))
 }
 
 krige_sk_arg_check <- function(y, V, Vp, Vop, m)
@@ -490,4 +579,155 @@ mspe_uk_arg_check <- function(w, V, Vp, Vop)
 		stop("The ncols in w must match ncols in Vop")
 	}
 
-}
\ No newline at end of file
+}
+
+condnorm_par_arg_check <- function(y, V, Vp, Vop, coeff, X, Xp, method)
+{
+	n <- length(y)
+	nk <- length(coeff)
+
+	if(!is.numeric(y))
+	{
+		stop("y must be a numeric vector")
+	}
+	if(!is.matrix(V) || !is.numeric(V) || (nrow(V)!= ncol(V)))
+	{
+		stop("V must be a square numeric matrix")
+	}
+	if(!is.matrix(Vp) || !is.numeric(Vp) || (nrow(Vp)!= ncol(Vp)))
+	{
+		stop("Vp must be a square numeric matrix")
+	}
+	if(!is.matrix(Vop) || !is.numeric(Vop))
+	{
+		stop("Vop must be a numeric matrix")
+	}
+	if(length(y) != nrow(V))
+	{
+		stop("length of y must match nrows of V")
+	}
+	if(length(y) != nrow(Vop))
+	{
+		stop("length of y must match nrows of Vop")
+	}
+	if(ncol(Vp) != ncol(Vop))
+	{
+		stop("ncols of Vp must match ncols of Vop")
+	}
+
+	if(!is.numeric(coeff))
+	{
+		stop("coeff must be a numeric vector")
+	}
+	if((is.null(X) && !is.null(Xp)) || (!is.null(X) && is.null(Xp)))
+	{
+		stop("If X is supplied, Xp must also be supplied (and vice versa)")
+	}
+	if(!is.null(X))
+	{
+		if(nrow(X) != n)
+		{
+			stop("nrows of X must match length of y")
+		}
+		if(ncol(X) != nk)
+		{
+			stop("ncols of X must match length of coeff")
+		}
+		if(nrow(Xp) != nrow(Vp))
+		{
+			stop("nrows of Xp must match nrows of Vp")
+		}
+		if(ncol(Xp) != ncol(X))
+		{
+			stop("ncols of Xp must match ncols of X")
+		}
+	}
+	if(!valid_decomp_type)
+	{
+		stop("method must be 'eigen', 'chol', or 'svd'")
+	}
+}
+
+rmvnorm_arg_check <- function(nsim, mu, V, method)
+{
+	if(!is.numeric(nsim) || !is.numeric(mu) || ! is.numeric(V))
+	{
+		stop("nsim, mu, and V arguments must all be numeric")
+	}
+	if(!isSymmetric(V) || !is.matrix(V))
+	{
+		stop("V must be a symmetrix matrix")
+	}
+	if(length(mu) != nrow(V))
+	{
+		stop("The length of mu must equal nrows of V")
+	}
+	if(!(method == "eigen" || method == "chol" || method == "svd"))
+	{
+		stop("method must be 'eigen', 'chol', or 'svd'")
+	}
+}
+
+rcondsim_arg_check <- function(nsim, y, V, Vp, Vop, Ve.diag, method = "eigen", krige.obj)
+{
+	if(!(is.numeric(nsim)))
+	{
+		stop("nsim must be a positive number")
+	}
+	if(length(nsim) != 1)
+	{
+		stop("nsim must be a vector of length 1")
+	}
+	if(!(nsim > 1))
+	{
+		stop("nsim must be at least 1")
+	}
+	if(!is.numeric(y) || !is.vector(y))
+	{
+		stop("y must be a numeric vector")
+	}
+	if(!is.matrix(V) || !is.numeric(V) || (nrow(V)!= ncol(V)))
+	{
+		stop("V must be a square numeric matrix")
+	}
+	if(length(y) != nrow(V))
+	{
+		stop("length(y) must equal nrow(V)")
+	}
+	if(!is.matrix(Vp) || !is.numeric(Vp) || (nrow(Vp)!= ncol(Vp)))
+	{
+		stop("Vp must be a square numeric matrix")
+	}
+	if(!is.matrix(Vop) || !is.numeric(Vop))
+	{
+		stop("Vop must be a numeric matrix")
+	}
+	if(length(y) != nrow(Vop))
+	{
+		stop("length(y) must equal nrow(Vop)")
+	}
+	if(ncol(Vp) != ncol(Vop))
+	{
+		stop("ncol(Vp) must equal ncol(Vop)")
+	}
+	if(!(is.vector(Ve.diag) && (is.numeric(Ve.diag))))
+	{
+		stop("Ve.diag must be a numeric vector")
+	}
+	if(length(y) != length(Ve.diag))
+	{
+		stop("Ve.diag must have the same length as y")
+	}
+	if(!(method == "eigen" || method == "chol" || method == "svd"))
+	{
+		stop("method must be 'eigen', 'chol', or 'svd'")
+	}	
+	if(!is.list(krige.obj))
+	{
+		stop("krige.obj should be an object returned by a kriging function and should contain w, a matrix of prediction weights for the observed data.")		
+	}
+	if(is.null(krige.obj$w))
+	{
+		stop("krige.obj should be an object returned by a kriging function and should contain w, a matrix of prediction weights for the observed data.")		
+	}
+}
